@@ -71,6 +71,11 @@ class Driver(driver.Driver):
             },
         ]
 
+    def validate_master_resize(self, node_count):
+        # This driver supports resizing to the same values
+        # as initial create, so re-use the Base class validation.
+        return self.validate_master_size(node_count)
+
     def _update_control_plane_nodegroup_status(self, cluster, nodegroup):
         # The status of the master nodegroup is determined by the Cluster API
         # control plane object
@@ -845,6 +850,11 @@ class Driver(driver.Driver):
             "cloudCredentialsSecretName": self._get_app_cred_name(cluster),
             "etcd": self._get_etcd_config(cluster),
             "apiServer": {
+                "associateFloatingIP": self._get_label_bool(
+                    cluster,
+                    "master_lb_floating_ip_enabled",
+                    True,
+                ),
                 "enableLoadBalancer": True,
                 "loadBalancerProvider": self._get_octavia_provider(cluster),
             },
